@@ -166,7 +166,7 @@ class SpColl(lp.Properties):
                     print("Improper property key")
                     exit()
 
-                my_prop.text = my_props[prop]
+                my_prop.text = str(my_props[prop])
 
     def _update_optional_properties(self, my_element, my_object):
         opt_props = my_element.xpath("optional_properties")
@@ -218,12 +218,15 @@ class SpColl(lp.Properties):
         xml_validator = etree.XMLSchema(file=url)
         xml_validator.assert_(xml)
 
-    def update_from_xml(self, file):
+    def update_from_xml(self, file, xpath = ""):
         """Method to update a species collection from an XML file.
 
         Args:
             ``file`` (:obj:`str`) The name of the XML file from which to update.
 
+            ``xpath`` (:obj:`str`, optional): XPath expression to select
+            species.  Defaults to all species.
+
         Returns:
             On successful return, the species collection has been updated.
 
@@ -237,7 +240,7 @@ class SpColl(lp.Properties):
 
         self._update_optional_properties(spcoll, self)
 
-        el_species = spcoll.xpath("//species")
+        el_species = spcoll.xpath("//species" + xpath)
 
         species = []
 
